@@ -139,6 +139,9 @@ setMethod("rast", signature(x="SpatVector"),
 	x <- trimws(x)
 	x <- x[x != ""]
 	
+	i <- substr(x, 1, 5) == "s3://" 
+	x[i] <- paste0("/vsis3/", substr(x[i], 6, nchar(x[i])))
+	
 	i <- substr(x, 1, 4) == "http" 
 	if (vsi) {
 		x[i] <- paste0("/vsicurl/", x[i])
@@ -148,7 +151,7 @@ setMethod("rast", signature(x="SpatVector"),
 	x <- enc2utf8(x)
 	p <- normalizePath(x, winslash = "/", mustWork = FALSE)
 	if (mustExist) {
-		i <- file.exists(p)
+		i <- file.exists(dirname(p))
 		x[i] <- p[i]
 	} else {
 		return(p)
