@@ -1,4 +1,14 @@
 
+set.seed(500)
+r <- rast(ext=c(0, 3, 0, 3), ncol = 3, nrow = 3, nlyr=2, vals=runif(18))
+pts <- cbind(c(0.5, 1.5), c(0.5, 1.5))
+vct <- terra::vect(pts)
+e <- terra::extract(r, vct, ID = FALSE)
+expect_equal(e[,1], c(0.5121819, 0.81227813))
+e <- terra::extract(r, vct, ID = FALSE, fun=sum)
+expect_equal(e[,1], c(0.5121819, 0.81227813))
+
+
 f <- system.file("ex/lux.shp", package="terra")
 y <- vect(f)[1:2,]
 
@@ -195,3 +205,14 @@ expect_equal(round(terra::extract(r, data.frame(X = -45.0, Y = 45.0), method = "
 m = rast(nrow = 2, ncol = 2, vals=1:4)
 expect_equal(cells(m), 1:4)
 
+
+v <- vect(system.file("ex/lux.shp", package="terra"))
+r <- rast(system.file("ex/elev.tif", package="terra"))
+
+fun <- function(x, ...) c(min(x, ...), mean(x, ...), max(x, ...))
+e <- extract(r, v, fun, na.rm=TRUE)[6,]
+expect_equivalent(round(e, 4), c(6, 164, 314.9969, 403))
+
+e <- extract(r, v, quantile, na.rm=TRUE)[12,]
+expect_equivalent(round(e), c(12, 213, 274, 317, 352, 413))
+
